@@ -37,8 +37,7 @@ import org.apache.maven.plugin.testing.AbstractMojoTestCase;
 import org.apache.maven.plugins.resources.stub.MavenProjectResourcesStub;
 import org.codehaus.plexus.PlexusContainer;
 import org.codehaus.plexus.util.FileUtils;
-import org.codehaus.plexus.util.IOUtil;
-import org.sonatype.aether.RepositorySystemSession;
+import org.eclipse.aether.RepositorySystemSession;
 
 public class ResourcesMojoTest
     extends AbstractMojoTestCase
@@ -347,8 +346,7 @@ public class ResourcesMojoTest
         MavenExecutionRequest request = new DefaultMavenExecutionRequest();
         request.setSystemProperties( System.getProperties() );
 
-        MavenSession mavenSession =
-            new MavenSession( (PlexusContainer) null, (RepositorySystemSession) null, request, null );
+        MavenSession mavenSession = new MavenSession( null, null, request, null );
         setVariableValueToObject( mojo, "session", mavenSession );
         mojo.execute();
 
@@ -358,15 +356,10 @@ public class ResourcesMojoTest
         assertTrue( userDir.exists() );
 
         Properties props = new Properties();
-        final FileInputStream inStream = new FileInputStream( new File( resourcesDir, "file4.txt" ) );
-        try
+        try ( FileInputStream inStream = new FileInputStream( new File( resourcesDir, "file4.txt" ) ) )
         {
             props.load( inStream );
         }
-        finally
-        {
-            inStream.close();
-        }
         File fileFromFiltering = new File( props.getProperty( "current-working-directory" ) );
 
         assertTrue( fileFromFiltering.getAbsolutePath() + " does not exist.", fileFromFiltering.exists() );
@@ -456,7 +449,7 @@ public class ResourcesMojoTest
         MavenProjectResourcesStub project = new MavenProjectResourcesStub( "resourcePropertyFiles_Filtering" );
         List<Resource> resources = project.getBuild()
                                 .getResources();
-        LinkedList<String> filterList = new LinkedList<String>();
+        LinkedList<String> filterList = new LinkedList<>();
 
         assertNotNull( mojo );
 
@@ -492,7 +485,7 @@ public class ResourcesMojoTest
         MavenProjectResourcesStub project = new MavenProjectResourcesStub( "resourcePropertyFiles_Extra" );
         List<Resource> resources = project.getBuild()
                                 .getResources();
-        LinkedList<String> filterList = new LinkedList<String>();
+        LinkedList<String> filterList = new LinkedList<>();
 
         assertNotNull( mojo );
 
@@ -528,8 +521,8 @@ public class ResourcesMojoTest
         MavenProjectResourcesStub project = new MavenProjectResourcesStub( "resourcePropertyFiles_MainAndExtra" );
         List<Resource> resources = project.getBuild()
                                 .getResources();
-        LinkedList<String> filterList = new LinkedList<String>();
-        LinkedList<String> extraFilterList = new LinkedList<String>();
+        LinkedList<String> filterList = new LinkedList<>();
+        LinkedList<String> extraFilterList = new LinkedList<>();
 
         assertNotNull( mojo );
 
@@ -576,7 +569,7 @@ public class ResourcesMojoTest
             new MavenProjectResourcesStub( "resourcePropertyFiles_Filtering_TokensInFilters" );
         final List<Resource> resources = project.getBuild()
                                       .getResources();
-        final LinkedList<String> filterList = new LinkedList<String>();
+        final LinkedList<String> filterList = new LinkedList<>();
 
         assertNotNull( mojo );
 
@@ -691,18 +684,9 @@ public class ResourcesMojoTest
         throws IOException
     {
         assertTrue( FileUtils.fileExists( fileName ) );
-
-        BufferedReader reader = null;
-        try
+        try( BufferedReader reader = new BufferedReader( new FileReader( fileName ) ) )
         {
-            reader = new BufferedReader( new FileReader( fileName ) );
             assertEquals( data, reader.readLine() );
-            reader.close();
-            reader = null;
-        }
-        finally
-        {
-            IOUtil.close( reader );
         }
     }
 
